OC.L10N.register(
    "core",
    {
    "Please select a file." : "Ju lutemi, përzgjidhni një kartelë.",
    "File is too big" : "Kartela është shumë e madhe",
    "Invalid file provided" : "U dha kartelë e pavlefshme",
    "No image or file provided" : "S’u dha figurë apo kartelë",
    "Unknown filetype" : "Lloj i panjohur kartele",
    "Invalid image" : "Figurë e pavlefshme",
    "An error occurred. Please contact your admin." : "Ndodhi një gabim. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "No temporary profile picture available, try again" : "S’ka gati foto të përkohshme profili, riprovoni",
    "No crop data provided" : "S’u dhanë të dhëna qethjeje",
    "No valid crop data provided" : "S’u dhanë të dhëna qethjeje të vlefshme",
    "Crop is not square" : "Qethja s’është katrore",
    "Couldn't reset password because the token is invalid" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i është i pavlefshëm",
    "Couldn't reset password because the token is expired" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i ka skaduar",
    "%s password changed successfully" : "Fjalëkalimi për %s u ndryshua me sukses",
    "%s password reset" : "U ricaktua fjalëkalimi për %s",
    "Couldn't send reset email. Please contact your administrator." : "S’u dërgua dot email-i i ricaktimit. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "Couldn't send mail to following users: %s " : "S’u dërgua dot e-mail përdoruesve vijues: %s ",
    "Preparing update" : "Po përgatitet përditësimi",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Sinjalizim ndreqjeje: ",
    "Repair error: " : "Gabim ndreqjeje: ",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ju lutemi, përdorni përditësuesin e rreshtit të urdhrave, sepse përditësimi i vetvetishëm është i çaktivizuar te config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Po kontrollohet tabela %s",
    "Turned on maintenance mode" : "U aktivizua mënyra mirëmbajtje",
    "Turned off maintenance mode" : "U çaktivizua mënyra mirëmbajtje",
    "Maintenance mode is kept active" : "Mënyra mirëmbajtje është mbajtur e aktivizuar",
    "Updating database schema" : "Po përditësohet skema e bazës së të dhënave",
    "Updated database" : "U përditësua baza e të dhënave",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
    "Checked database schema update" : "U kontrollua përditësimi i skemës së bazës së të dhënave",
    "Checking updates of apps" : "Po kontrollohen përditësime të aplikacionit",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave për %s (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
    "Checked database schema update for apps" : "U kontrollua përditësimi i skemës së bazës së të dhënave për aplikacionet",
    "Updated \"%s\" to %s" : "U përditësua \"%s\" në %s",
    "Set log level to debug" : "Caktoni shkallë regjistrimi për diagnostikimin",
    "Reset log level" : "Rikthe te parazgjedhja shkallën e regjistrimit",
    "Starting code integrity check" : "Po fillohet kontroll integriteti për kodin",
    "Finished code integrity check" : "Përfundoi kontrolli i integritetit për kodin",
    "%s (3rdparty)" : "%s (prej palësh të treta)",
    "%s (incompatible)" : "%s (e papërputhshme)",
    "Following apps have been disabled: %s" : "Janë çaktivizuar aplikacionet vijuese : %s",
    "Already up to date" : "Tashmë e përditësuar",
    "Sunday" : "E dielë",
    "Monday" : "E hënë",
    "Tuesday" : "E martë",
    "Wednesday" : "E mërkurë",
    "Thursday" : "E enjte",
    "Friday" : "E premte",
    "Saturday" : "E shtunë",
    "Sun." : "Die.",
    "Mon." : "Hën.",
    "Tue." : "Mar.",
    "Wed." : "Mër.",
    "Thu." : "Enj.",
    "Fri." : "Pre.",
    "Sat." : "Sht.",
    "Su" : "Di",
    "Mo" : "Hë",
    "Tu" : "Ma",
    "We" : "Më",
    "Th" : "En",
    "Fr" : "Pr",
    "Sa" : "Sh",
    "January" : "Janar",
    "February" : "Shkurt",
    "March" : "Mars",
    "April" : "Prill",
    "May" : "Maj",
    "June" : "Qershor",
    "July" : "Korrik",
    "August" : "Gusht",
    "September" : "Shtator",
    "October" : "Tetor",
    "November" : "Nëntor",
    "December" : "Dhjetor",
    "Jan." : "Jan.",
    "Feb." : "Shk.",
    "Mar." : "Mar.",
    "Apr." : "Pri.",
    "May." : "Maj.",
    "Jun." : "Qer.",
    "Jul." : "Kor.",
    "Aug." : "Gus.",
    "Sep." : "Sht.",
    "Oct." : "Tet.",
    "Nov." : "Nën.",
    "Dec." : "Dhj.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Pati probleme me kontrollin e integritetit të kodit. Më tepër të dhëna…</a>",
    "Settings" : "Rregullime",
    "Problem loading page, reloading in 5 seconds" : "Gabim në ngarkimin e faqes, do të ringarkohet pas 5 sekondash",
    "Saving..." : "Po ruhet …",
    "Dismiss" : "Mos e merr parasysh",
    "seconds ago" : "sekonda më parë",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Lidhja për ricaktimin e fjalëkalimi tuaj u dërgua tek email-i juaj. Nëse nuk e merrni brenda një kohe të arsyeshme, kontrolloni dosjet e postës së padëshirueshme/postës së pavlerë.<br>Nëse s’është as aty, pyetni përgjegjësin tuaj lokal.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Kartelat tuaja janë të fshehtëzuara. Nëse s’keni aktivizuar kyçin e rimarrjeve, nuk do të ketë ndonjë rrugë për të marrë sërish të dhënat tuaja pasi të jetë ricaktuar fjalëkalimi juaj.<br />Nëse s’jeni i sigurt se ç’duhet bërë, ju lutemi, përpara se të vazhdoni, lidhuni me përgjegjësin tuaj. <br />Doni vërtet të vazhdoni?",
    "I know what I'm doing" : "E di se ç’bëj",
    "Password can not be changed. Please contact your administrator." : "Fjalëkalimi nuk mund të ndryshohet. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "No" : "Jo",
    "Yes" : "Po",
    "Choose" : "Zgjidhni",
    "Error loading file picker template: {error}" : "Gabim në ngarkimin e gjedhes së marrësit të kartelave: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Gabim gjatë ngarkimit të gjedhes së mesazheve: {error}",
    "read-only" : "vetëm për lexim",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} përplasje kartelash","{count} përplasje kartelash"],
    "One file conflict" : "Një përplasje kartele",
    "New Files" : "Kartela të Reja",
    "Already existing files" : "Kartela ekzistuese",
    "Which files do you want to keep?" : "Cilat kartela doni të mbani?",
    "If you select both versions, the copied file will have a number added to its name." : "Nëse përzgjidhni të dy versionet, kartelës së kopjuar do t’i shtohet një numër në emrin e saj.",
    "Cancel" : "Anuloje",
    "Continue" : "Vazhdo",
    "(all selected)" : "(krejt të përzgjedhurat)",
    "({count} selected)" : "({count} të përzgjedhura)",
    "Error loading file exists template" : "Gabim në ngarkimin e gjedhes kartela ekziston",
    "Very weak password" : "Fjalëkalim shumë i dobët",
    "Weak password" : "Fjalëkalim i dobët",
    "So-so password" : "Fjalëkalim çka",
    "Good password" : "Fjalëkalim i mirë",
    "Strong password" : "Fjalëkalim i fortë",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Shërbyesi juaj web ende s’është rregulluar për të lejuar njëkohësim kartelash, ngaqë ndërfaqja WebDAV duket se është e dëmtuar.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Shërbyesi juaj s’është rregulluar si duhet për të kuptuar \"{url}\". Të dhëna të mëtejshme mund të gjenden te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Ky shërbyes nuk ka lidhje Internet që funksionon. Kjo do të thotë që disa prej veçorive, të tilla si montimi i depozitave të jashtme, njoftimet mbi përditësime apo instalim aplikacionesh nga palë të treta, s’do të funksionojnë. Edhe hyrja në kartela së largëti, apo dërgimi i email-eve për njoftime mund të mos funksionojnë. Këshillojmë të aktivizoni për këtë shërbyes lidhjen në Internet, nëse doni t’i keni krejt këto veçori.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "S’ka të formësuar fshehtinë kujtese. Që të përmirësoni punimin, ju lutemi formësoni një të tillë, në pastë. Më tepër të dhëna mund të gjeni te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom s’lexohet dot nga PHP-ja, çka shkëshillohet me forcë, për arsye sigurie. Më tepër të dhëna mund të gjenden te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Po xhironi PHP {version}. Ju nxisim të përmirësoni versionin e PHP-së që të përfitoni <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">nga përditësimet e punimit dhe sigurisë të ofruara PHP Group</a>, sapo të mbulohet nga shpërndarja juaj.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Formësimi për krye ndërmjetësi prapësor është i pasaktë, ose jeni duke hyrë në ownCloud prej një ndërmjetësi të besuar. Nëse s’jeni duke hyrë në ownCloud prej një ndërmjetësi të besuar, ky është një problem sigurie dhe mund t’i lejojë një agresori të maskojë adresën e vet IP si një të pranueshme nga ownCloud-i. Të dhëna të mëtejshme mund të gjeni te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached është formësuar si fshehtinë e shpërndarë, por është instaluar moduli i gabuar PHP \"memcache\". \\OC\\Memcache\\Memcached mbulon vetëm \"memcached\" dhe jo \"memcache\". Shihni <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki-n mbi memcached rreth të dy moduleve</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Disa kartela s’e kaluan dot kontrollin e pacenueshmërisë. Më tepër të dhëna se si të zgjidhet ky problem mund të gjeni te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë. (<a href=\"{codeIntegrityDownloadEndpoint}\">Listë e kartelave të pavlefshme…</a> / <a href=\"{rescanEndpoint}\">Rikontrollojini…</a>)",
    "Error occurred while checking server setup" : "Ndodhi një gabim gjatë kontrollit të rregullimit të shërbyesit",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Drejtoria juaj e të dhënave dhe kartelat tuaja ka shumë mundësi të jenë të arritshme që nga interneti. Kartela .htaccess s’funksionon. Këshillojmë me forcë që ta formësoni shërbyesin tuaj web në një mënyrë që drejtoria e të dhënave të mos lejojë më hyrje, ose ta zhvendosni drejtorinë e të dhënave jashtë rrënjës së dokumenteve të shërbyesit web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Kryet HTTP \"{header}\" s’është formësuar të jetë i njëjtë me \"{expected}\". Ky është një rrezik potencial sigurie dhe privatësie dhe këshillojmë të ndreqet ky rregullim.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Parametri \"Strict-Transport-Security\" HTTP s’është formësuar të paktën \"{seconds}\" sekonda. Për siguri të thelluar, ju këshillojmë aktivizimin e HSTS-së, ashtu si përshkruhet në <a href=\"{docUrl}\" rel=\"noreferrer\">këshillat tona mbi sigurinë</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Po e përdorni këtë sajt përmes HTTP-je. Këshillojmë me forcë ta formësoni shërbyesin tuaj të kërkojë medoemos përdorimin e HTTPS-së, siç përshkruhet te <a href=\"{docUrl}\">këshillat tona mbi sigurinë</a>.",
    "Shared" : "Ndarë",
    "Shared with {recipients}" : "Ndarë me {recipients}",
    "Error" : "Gabim",
    "Error while sharing" : "Gabim gjatë ndarjes",
    "Error while unsharing" : "Gabim gjatë heqjes së ndarjes",
    "The public link will expire no later than {days} days after it is created" : "Lidhja publike do të skadojë jo më vonë se {days} ditë pas krijimit të saj",
    "Set expiration date" : "Caktoni datë skadimi",
    "Expiration" : "Skadim",
    "Expiration date" : "Datë skadimi",
    "Expiration date is required" : "Data e skadimit është e domosdoshme",
    "Delete {link}" : "Fshije {link}",
    "Remove link" : "Hiqe lidhjen",
    "{fileName} link" : "lidhje {fileName}",
    "Link" : "Lidhje",
    "Create public link" : "Krijoni lidhje publike",
    "Edit" : "Përpunoni",
    "Remove" : "Hiqe",
    "Click to copy to clipboard" : "Klikoni që të kopjohet në të papastër",
    "Social share" : "Ndarje në rrjete shoqërore",
    "There are currently no link shares, you can create one" : "Deri këtu s’ka ndarje lidhjesh, mund të krijoni një të tillë",
    "Anyone with the link has access to the file/folder" : "Cilido që zotëron lidhjen, ka hyrje te kartela/dosja",
    "Copied!" : "U kopjua!",
    "Not supported!" : "Nuk mbulohet!",
    "Press ⌘-C to copy." : "Shtypni ⌘-C që të kopjohet.",
    "Press Ctrl-C to copy." : "Shtypni Ctrl-C që të kopjohet.",
    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
    "Password required" : "Lypset fjalëkalim",
    "Filename" : "Emër kartele",
    "Password" : "Fjalëkalim",
    "Name" : "Emër",
    "Allow editing" : "Lejo përpunim",
    "Show file listing" : "Shfaq listë kartelash",
    "Edit link share: {name}" : "Përpunoni ndarje lidhjesh: {name}",
    "Save" : "Ruaje",
    "Create link share: {name}" : "Krijoni ndarje lidhjesh: {name}",
    "Remove password" : "Hiqe fjalëkalimin",
    "Share to Twitter. Opens in a new window." : "Ndajeni me të tjerët në Twitter. Hapet në një dritare të re.",
    "Share to Facebook. Opens in a new window." : "Ndajeni me të tjerët në Facebook. Hapet në një dritare të re.",
    "Share to Diaspora. Opens in a new window." : "Ndajeni me të tjerët në Diaspora. Hapet në një dritare të re.",
    "Share to Google+. Opens in a new window." : "Ndajeni me të tjerët në Google+. Hapet në një dritare të re.",
    "Share via email. Opens your mail client." : "Ndajeni me të tjerët me email. Hap klientin tuaj për email-e.",
    "Error while sending notification" : "Gabim gjatë dërgimit të njoftimit",
    "Sending ..." : "Po dërgohet …",
    "Email sent" : "Email-i u dërgua",
    "Email link to person" : "Dërgoja personit lidhjen me email",
    "Send link via email" : "Dërgojeni lidhjen me email",
    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
    "group" : "grup",
    "remote" : "i largët",
    "notify by email" : "njofto me email",
    "Unshare" : "Hiqe ndarjen",
    "can share" : "mund të ndajnë",
    "can edit" : "mund të përpunojnë",
    "create" : "krijoje",
    "change" : "ndërroje",
    "delete" : "fshije",
    "access control" : "kontroll hyrjesh",
    "Could not unshare" : "S’e shndau dot",
    "Share details could not be loaded for this item." : "Për këtë objekt s’u ngarkuan dot hollësi ndarjeje.",
    "No users or groups found for {search}" : "S’u gjetën përdorues ose grupe për {search}",
    "No users found for {search}" : "S’u gjet përdorues për {search}",
    "An error occurred. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
    "{sharee} (group)" : "{sharee} (grup)",
    "{sharee} (at {server})" : "{sharee} (në {server})",
    "{sharee} (remote)" : "{sharee} (i largët)",
    "Share" : "Ndaje",
    "User and Groups" : "Përdorues dhe Grupe",
    "Public Links" : "Lidhje Publike",
    "Resharing is not allowed" : "Nuk lejohen rindarjet",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Ndajeni me persona në ownCloud-e të tjera duke përdorur sintaksën username@example.com/owncloud",
    "Share with users…" : "Ndajeni me përdorues…",
    "Share with users, groups or remote users…" : "Ndajeni me përdorues, grupe ose përdorues të largët…",
    "Share with users or groups…" : "Ndajeni me përdorues ose grupe…",
    "Share with users or remote users…" : "Ndajeni me përdorues ose përdorues të largët…",
    "Error removing share" : "Gabim në heqjen e ndarjes",
    "Warning" : "Kujdes",
    "Non-existing tag #{tag}" : "Etiketë #{tag} që s’ekziston",
    "restricted" : "e kufizuar",
    "invisible" : "e padukshme",
    "({scope})" : "({scope})",
    "Delete" : "Fshije",
    "Rename" : "Riemërtoje",
    "Collaborative tags" : "Etiketa bashkëpunimi",
    "The object type is not specified." : "S’është specifikuar lloji i objektit.",
    "Enter new" : "Jep të ri",
    "Add" : "Shtoni",
    "Edit tags" : "Përpunoni etiketa",
    "Error loading dialog template: {error}" : "Gabim gjatë ngarkimit të gjedhes së dialogut: {error}",
    "No tags selected for deletion." : "S’u përzgjodhën etiketa fshirje.",
    "unknown text" : "tekst i panjohur",
    "Hello world!" : "Hello world!",
    "sunny" : "me diell",
    "Hello {name}, the weather is {weather}" : "Tungjatjeta {name}, koha është {weather}",
    "Hello {name}" : "Tungjatjeta {name}",
    "new" : "i ri",
    "_download %n file_::_download %n files_" : ["shkarko %n kartelë","shkarko %n kartela"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Përmirësimi po kryhet, braktisja e kësaj faqeje mund ta ndërpresë procesin në disa mjedise.",
    "Updating to {version}" : "Po përditësohet me {version}",
    "An error occurred." : "Ndodhi një gabim.",
    "Please reload the page." : "Ju lutemi, ringarkoni faqen.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Përditësimi qe i pasuksesshëm. Për më tepër të dhëna <a href=\"{url}\">shihni postimin te forumi ynë</a> lidhur me këtë çështje.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Përditësimi dështoi. Ju lutemi, njoftojani këtë problem <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">bashkësisë ownCloud</a>.",
    "The update was successful. There were warnings." : "Përditësimi qe i suksesshëm. Pati sinjalizime.",
    "The update was successful. Redirecting you to ownCloud now." : "Përditësimi qe i suksesshëm. Po ridrejtoheni te ownCloud-i.",
    "Searching other places" : "Po kërkohet në vende të tjera",
    "No search results in other folders" : "S’u gjetën përfundime në dosje të tjera",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} përfundim kërkimi në një tjetër dosje","{count} përfundime kërkimi në dosje të tjera"],
    "Personal" : "Personale",
    "Users" : "Përdorues",
    "Apps" : "Aplikacione",
    "Admin" : "Admin",
    "Help" : "Ndihmë",
    "Access forbidden" : "Ndalohet hyrja",
    "File not found" : "S’u gjet kartelë",
    "The specified document has not been found on the server." : "Dokumenti i përcaktuar s’u gjet në shërbyes.",
    "You can click here to return to %s." : "Mund të klikoni këtu për t’u kthyer te %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Njatjeta,\n\nthjesht po ju bëjmë të ditur që %s ndau me ju %s.\nShiheni: %s\n\n",
    "The share will expire on %s." : "Ndarja do të skadojë më %s.",
    "Cheers!" : "Gëzuar!",
    "Internal Server Error" : "Gabim i Brendshëm Shërbyesi",
    "The server encountered an internal error and was unable to complete your request." : "Shërbyesi hasi një gabim të brendshëm dhe s’qe në gjendje të plotësojë kërkesën tuaj.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Nëse ky gabim shfaqet shumë herë, ju lutemi, lidhuni me përgjegjësin e shërbyesit, dhe përfshini hollësitë teknike më poshtë në njoftimin tuaj.",
    "More details can be found in the server log." : "Më tepër hollësi mund të gjenden në regjistrin e shërbyesit.",
    "Technical details" : "Hollësi teknike",
    "Remote Address: %s" : "Adresë e Largët: %s",
    "Request ID: %s" : "ID Kërkese: %s",
    "Type: %s" : "Lloj: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Mesazh: %s",
    "File: %s" : "Kartelë: %s",
    "Line: %s" : "Rresht: %s",
    "Trace" : "Gjurmim",
    "Create an <strong>admin account</strong>" : "Krijoni një <strong>llogari administruesi</strong>",
    "Username" : "Emër përdoruesi",
    "Storage & database" : "Depozitë & bazë të dhënash",
    "Data folder" : "Dosje të dhënash",
    "Configure the database" : "Formësoni bazën e të dhënave",
    "Only %s is available." : "Vetëm %s është gati.",
    "Install and activate additional PHP modules to choose other database types." : "Që të zgjidhni të tjera lloje bazash të dhënash, instaloni dhe aktivizoni module PHP shtesë.",
    "For more details check out the documentation." : "Për më tepër të dhëna shihni dokumentimin.",
    "Database user" : "Përdorues baze të dhënash",
    "Database password" : "Fjalëkalim baze të dhënash",
    "Database name" : "Emër baze të dhënash",
    "Database tablespace" : "Tablespace baze të dhënash",
    "Database host" : "Strehë baze të dhënash",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Ju lutemi, përcaktoni numrin e portës tok me emrin e strehës (p.sh., localhost: 5432).",
    "Performance warning" : "Sinjalizim funksionimi",
    "SQLite will be used as database." : "Si bazë të dhënash do të përdoret SQLite.",
    "For larger installations we recommend to choose a different database backend." : "Për instalime më të mëdha këshillojmë të zgjidhni një tjetër program shërbyesi baze të dhënash.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Përdorimi i SQLite-it shkëshillohet veçanërisht, kur për njëkohësim kartelash përdoret klienti desktop.",
    "Finish setup" : "Përfundoje rregullimin",
    "Finishing …" : "Po përfundohet …",
    "Need help?" : "Ju duhet ndihmë?",
    "See the documentation" : "Shihni dokumentimin",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Njatjeta,<br><br>thjesht po ju bëjmë të ditur që %s ndau me ju <strong>%s</strong>.<br><a href=\"%s\">Shiheni!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ky aplikacion lyp JavaScript për punim të saktë. Ju lutemi, {linkstart}aktivizoni JavaScript-in{linkend} dhe ringarkoni faqen.",
    "Log out" : "Dilni",
    "Search" : "Kërko",
    "Server side authentication failed!" : "Mirëfilltësimi më anë të shërbyesit dështoi!",
    "Please contact your administrator." : "Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "An internal error occurred." : "Ndodhi një gabim i brendshëm.",
    "Please try again or contact your administrator." : "Ju lutemi, riprovoni ose lidhuni me përgjegjësin tuaj.",
    "Username or email" : "Emër përdoruesi ose email",
    "Log in" : "Hyni",
    "Wrong password. Reset it?" : "Fjalëkalim i gabuar. Të ricaktohet?",
    "Wrong password." : "Fjalëkalim i gabuar.",
    "Stay logged in" : "Qëndro i futur",
    "Alternative Logins" : "Hyrje Alternative",
    "Use the following link to reset your password: {link}" : "Që të ricaktoni fjalëkalimin tuaj, përdorni lidhjen vijuese: {link}",
    "Password changed successfully" : "Fjalëkalimi u ndryshua me sukses",
    "New password" : "Fjalëkalim i ri",
    "New Password" : "Fjalëkalim i Ri",
    "Reset password" : "Ricaktoni fjalëkalimin",
    "This ownCloud instance is currently in single user mode." : "Kjo instancë ownCloud është aktualisht në gjendjen me përdorues të vetëm.",
    "This means only administrators can use the instance." : "Kjo do të thotë që instancën mund ta përdorin vetëm administratorët.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Nëse ky mesazh shfaqet vazhdimisht ose u shfaq papritmas, lidhuni me përgjegjësin e sistemit.",
    "Thank you for your patience." : "Ju faleminderit për durimin.",
    "Two-step verification" : "Verifikim dyhapësh",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Siguria e zgjeruar është aktivizuar për llogarinë tuaj. Ju lutemi, bëni mirëfilltësimin duke përdorur një faktor të dytë.",
    "Cancel login" : "Anuloje hyrjen",
    "Please authenticate using the selected factor." : "Ju lutemi, bëni mirëfilltësimin duke përdorur faktorin e përzgjedhur.",
    "An error occurred while verifying the token" : "Ndodhi një gabim gjatë verifikimit të token-it",
    "You are accessing the server from an untrusted domain." : "Po hyni në shërbyes nga një përkatësi jo e besuar.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Ju lutemi, lidhuni me përgjegjësin tuaj. Nëse jeni një përgjegjës në këtë instancë, formësoni rregullimin \"trusted_domains\" te config/config.php. Një formësim shembull jepet te config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Në varësi të formësimit tuaj, si administrator mundet gjithashtu të jeni në gjendje të përdorni butonin më poshtë për ta besuar këtë përkatësi.",
    "Add \"%s\" as trusted domain" : "Shtojeni \"%s\" si përkatësi të besuar",
    "App update required" : "Lypset përditësim aplikacioni",
    "%s will be updated to version %s" : "%s do të përditësohet me versionin %s",
    "These apps will be updated:" : "Do të përditësohen këto aplikacione:",
    "The theme %s has been disabled." : "Tema %s u çaktivizua.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ju lutemi, para se të vazhdoni më tej, sigurohuni që baza e të dhënave, dosja e formësimeve dhe dosja e të dhënave janë kopjeruajtur.",
    "Start update" : "Fillo përditësimin",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Për të shmangur çaste bllokimi pune me instalime të mëdha, mundeni të ekzekutoni urdhrin vijues që nga drejtoria juaj e instalimit:",
    "Detailed logs" : "Regjistrime të hollësishme",
    "Update needed" : "Lyp përditësim",
    "Please use the command line updater because you have a big instance." : "Ju lutemi, përdorni përditësuesin e rreshtit të urdhrave, sepse keni një instalim të madh.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Për ndihmë, shihni  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentimin</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Kjo instancë %s hëpërhë gjendet nën mënyrën mirëmbajtje, çka mund të zgjasë ca.",
    "This page will refresh itself when the %s instance is available again." : "Kjo faqe do të rifreskohet vetiu, sapo instanca %s të jetë sërish gati.",
    "Could not reset password because the token is invalid" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i është i pavlefshëm",
    "Could not reset password because the token expired" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i ka skaduar",
    "Could not reset password because the token does not match" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i nuk përputhet",
    "Copy to clipboard" : "Kopjoje në të papastër",
    "Choose a password" : "Zgjidhni një fjalëkalim",
    "Upload only" : "Vetëm ngarkim",
    "Sending" : "Po dërgohet",
    "Menu" : "Menu",
    "Read only" : "Vetëm për lexim",
    "Read & Write" : "Lexim & Shkrim",
    "Email notification not sent" : "Njoftimi me email s’u dërgua",
    "You took too long to login, please try again now" : "U vonuat shumë me hyrjen, ju lutemi, riprovoni tani",
    "Choose an expiration date" : "Zgjidhni një datë skadimi",
    "An error occured" : "Ndodhi një gabim",
    "Send copy to self" : "Dërgojini vetes një kopje",
    "Add personal message" : "Shtoni mesazh personal",
    "Error adding {addItem}: {addItem} already exists" : "Gabim në shtimin e {addItem}: {addItem} ekziston tashmë",
    "federated" : "i federuar",
    "Link name" : "Emër lidhjeje",
    "Recipients can view, download, edit, delete and upload contents." : "Marrësit mund të shohin shkarkojnë, përpunojnë, fshijnë dhe ngarkojnë lëndë.",
    "Download / View" : "Të shkarkojë / Të shohë",
    "Download / View / Upload" : "Të shkarkojë / Të shohë / Të ngarkojë",
    "An error occured while sending email" : "Ndodhi një gabim gjatë dërgimit të email-it",
    "Owner: {owner}" : "I zoti: {owner}",
    "Email notification was sent!" : "Njoftimi me email u dërgua!",
    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Ju lutemi, nëse ky gabim rishfaqet shumë herë, lidhuni me përgjegjësin e shërbyesit dhe në njoftimin tuaj përfshini hollësitë teknike të mëposhtme.",
    "You are trying to access a private link. Please log in first." : "Po provoni të hapni një lidhje private. Ju lutemi, më parë bëni hyrjen.",
    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Duket sikur instanca juaj mund të strehojë shumë kartela dhe/ose përdorues. Për të garantuar një proces të rrjedhshëm përmirësimi, ju lutemi, përdorni përpunuesin për rresht urdhrash (occ upgrade).",
    "Couldn't send mail to following recipient(s): %s " : "S’u dërgua dot postë te marrësi(t) vijues: %s ",
    "Receive files from multiple recipients without revealing the contents of the folder." : "Merr kartela prej të tjerësh pa e zbuluar lëndën e dosjes.",
    "Recipients can view or download contents." : "Marrësit mund të shohin dhe shkarkojnë lëndë.",
    "{sharee} (federated)" : "{sharee} (i federuar)",
    "Personal note from the sender: %s." : "Shënim personal nga dërguesi: %s.",
    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Përditësimi i vetvetishëm është i çaktivizuar te config.php. Që të përmirësoni instancën tuaj, ju lutemi, përdorni përditësuesin për rresht urdhrash (occ upgrade).",
    "Imprint" : "Imprint",
    "E-Mail sent" : "Email-i u dërgua",
    "Privacy Policy" : "Rregulla Privatësie",
    "Personal note from the sender: <br> %s." : "Shënim personal nga dërguesi: <br> %s."
},
"nplurals=2; plural=(n != 1);");
